/**
 * Copyright (c) 2014, MindFusion LLC - Bulgaria.
 */

import java.awt.*;
import java.io.*;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import org.w3c.dom.Document;

import com.mindfusion.drawing.*;
import com.mindfusion.diagramming.*;
import com.mindfusion.diagramming.components.*;
import com.mindfusion.diagramming.components.TextComponent;


public class OrgChartNode extends CompositeNode
{
	static Document xmlTemplate = loadXmlFile("OrgChartNode.xml");

	public OrgChartNode(Diagram diagram)
	{
		super(diagram);

		// create components from XML template
		getComponents().add(XmlLoader.load(xmlTemplate, null, null));

		// find components by name
		shape = (ShapeComponent) findComponent("Shape");
		image = (ImageComponent) findComponent("Image");
		title = (TextComponent) findComponent("Title");
		fullName = (TextComponent) findComponent("FullName");
		text = (TextComponent) findComponent("Text");

		// customize appearance
		title.getTextFormat().setHorizontalAlign(Align.Near);
		fullName.getTextFormat().setHorizontalAlign(Align.Near);
		text.getTextFormat().setHorizontalAlign(Align.Near);
		shape.setIsOutline(true);
		setFill(new SolidBrush(Color.WHITE));
		setStroke(new Pen(Color.BLACK, 0.5));
	}
	
	static Document loadXmlFile(String filepath)
	{
		DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
		factory.setIgnoringElementContentWhitespace(true);
		factory.setNamespaceAware(true);

		Document document = null;
		DocumentBuilder builder;
		try
		{
			File file = new File(filepath);
			builder = factory.newDocumentBuilder();
			document = builder.parse(file); 
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}
		return document;
	}

	public Pen getStroke()
	{
	    return shape.getPen();
	}
	
	public void setStroke(Pen value)
	{
		shape.setPen(value);
		this.repaint();
	}
	
	public Brush getFill()
	{
	    return shape.getBrush();
	}
	
	public void setFill(Brush value)
	{
		shape.setBrush(value);
	}

	public Image getImage()
	{
		return image.getImage();   
	}
	
	public void setImage(Image value)
	{
		image.setImage(value);
	}

	public String getTitle()
	{
	    return title.getText();
	}
	
	public void setTitle(String value)
	{
		title.setText(value);
	}

	public String getFullName()
	{
	    return fullName.getName();
	}
	
	public void setFullName(String value)
	{
		fullName.setText(value);
	}

	public String getText()
	{
		return text.getText();
	}
	
	public void setText(String value)
	{
		text.setText(value);
	}
	
	private ShapeComponent shape;
	private ImageComponent image;
	private TextComponent title;
	private TextComponent fullName;
	private TextComponent text;
}